# CS107 Group #8
[![Build Status](https://travis-ci.com/berry12kiwi/cs107-FinalProject.svg?token=hhtUVPNGzpLmk5cBYMMW&branch=master)](https://travis-ci.com/berry12kiwi/cs107-FinalProject)
[![codecov](https://codecov.io/gh/berry12kiwi/cs107-FinalProject/branch/master/graph/badge.svg?token=H1U66ARZYL)](undefined)

Group Members(in alphabetical order)
- Qinyi Chen, Sarah Zeng, Xingyu Liu
